@@ -1,6 +1,6 @@
 package Proc::tored;
-# ABSTRACT: Service management using a pid file and signals
-$Proc::tored::VERSION = '0.05';
+# ABSTRACT: Service management using a pid file and touch files
+$Proc::tored::VERSION = '0.06';
 use strict;
 use warnings;
 require Exporter;
@@ -36,11 +36,11 @@ __END__
 
 =head1 NAME
 
-Proc::tored - Service management using a pid file and signals
+Proc::tored - Service management using a pid file and touch files
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -59,7 +59,7 @@ version 0.05
 
 =head1 DESCRIPTION
 
-A C<Proc::tored> service is voluntarily managed by a pid file and signals.
+A C<Proc::tored> service is voluntarily managed by a pid file and touch files.
 
 =head1 EXPORTED SUBROUTINES
 
@@ -108,35 +108,14 @@ file), returns the pid of that process. Returns 0 otherwise.
 
 =head2 zap
 
-Sends a C<SIGTERM> to a running instance of the service, causing it to
-self-terminate (assuming it is also C<Proc::tored>). Accepts an optional
-C<$timeout> in fractional seconds, causing C<zap> to wait up to C<$timeout>
-seconds for the process to exit.
+Signals a running instance of the service that it should self-terminate
+(assuming it is also C<Proc::tored>). Accepts an optional C<$timeout> in
+fractional seconds, causing C<zap> to wait up to C<$timeout> seconds for the
+process to exit.
 
   zap $service, 30
     or die 'timed out after 30s waiting for service to exit';
 
-=head1 CAVEATS
-
-=head2 Threads
-
-A C<Proc::tored> service voluntarily self-terminates when it receives one of
-C<SIGTERM>, C<SIGINT>, C<SIGHUP>, or C<SIGPIPE>. On threaded perls, only the
-main thread receives signals. It is highly likely that a C<Proc::tored> service
-started outside the main thread will not respond to being L</zap>ped by another
-process.
-
-See B<catching signals> under L<http://perldoc.perl.org/threads.html#WARNINGS>
-for details.
-
-=head2 MSWin32
-
-The same warnings about threads apply to forked processes on MSWin32 perls as
-a result of C<fork()> being implemented using threads on that platform.
-
-See the notes regarding pseudoprocesses under
-L<http://perldoc.perl.org/perlfork.html#kill()>.
-
 =head1 AUTHOR
 
 Jeff Ober <jeffober@gmail.com>
