@@ -1,13 +1,13 @@
 package Proc::tored::Manager;
 # ABSTRACT: OO interface to creating a proctored service
-$Proc::tored::Manager::VERSION = '0.05';
+$Proc::tored::Manager::VERSION = '0.06';
 
 use strict;
 use warnings;
 use Moo;
 use Carp;
 use Fcntl qw(:flock :seek :DEFAULT);
-use Guard qw(guard scope_guard);
+use Guard qw(guard);
 use Path::Tiny qw(path);
 use Time::HiRes qw(sleep);
 use Try::Tiny;
@@ -15,7 +15,7 @@ use Type::Utils qw(declare as where);
 use Types::Standard qw(Str Bool Num is_CodeRef);
 
 my $NonEmptyStr = declare, as Str, where { $_ =~ /\S/ };
-my $Directory = declare, as $NonEmptyStr, where { -d $_ };
+my $Directory = declare, as $NonEmptyStr, where { -d $_ && -w $_ };
 
 with 'Proc::tored::Role::Running';
 
@@ -32,6 +32,16 @@ has name => (
   required => 1,
 );
 
+has '+term_file' => (
+  is => 'lazy',
+);
+
+sub _build_term_file {
+  my $self = shift;
+  my $file = path($self->dir)->child($self->name . '.term');
+  return "$file";
+}
+
 
 has filepath => (
   is  => 'lazy',
@@ -41,7 +51,8 @@ has filepath => (
 
 sub _build_filepath {
   my $self = shift;
-  sprintf '%s/%s.pid', $self->dir, $self->name;
+  my $file = path($self->dir)->child($self->name . '.pid');
+  return "$file";
 }
 
 
@@ -88,7 +99,7 @@ sub stop_running_process {
   my $pid = $self->running_pid || return 0;
   return $self->stop if $pid == $$;
 
-  if (kill('TERM', $pid) > 0) {
+  if ($self->signal > 0) {
     if ($timeout) {
       while (kill(0, $pid) && $timeout > 0) {
         sleep $sleep;
@@ -184,7 +195,7 @@ Proc::tored::Manager - OO interface to creating a proctored service
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -224,6 +235,18 @@ pid file.
 A valid directory path where the pid file is to be created or an existing pid
 file is to be found.
 
+=item term_file
+
+By default (and on supported platforms), posix signals are used to signal a
+managed process to voluntarily self-terminate. On non-compliant systems (e.g.
+MSWin32), a touch file is used instead. The path to this file is automatically
+constructed from L</name> in L</dir> unless manually specified.
+
+=item filepath
+
+Unless manually specified, the pid file's C<filepath> is constructed from
+L</name> in L</dir>.
+
 =back
 
 =head2 filepath
@@ -238,16 +261,7 @@ See L<Proc::tored::Role::Running/is_running>.
 =head2 service
 
 Accepts a code ref which will be called repeatedly until it or L</is_running>
-return false. While the service is running, handlers for C<SIGTERM>, C<SIGINT>,
-C<SIGPIPE>, and C<SIGHUP> are installed. When one of these signals are
-received, L</is_running> will be set to false and service loop will
-self-terminate.
-
-Note that it is possible for a signal to arrive between the L</is_running>
-check and the execution of the code ref. If this is a concern for the caller,
-it is recommended that the code ref avoid blocking for long periods, such as
-extended C<sleep> times or long-running database queries which perl cannot
-interrupt.
+return false.
 
 Example using a pool of forked workers, an imaginary task queue, and a
 secondary condition that decides whether to stop running (aside from the
@@ -283,16 +297,20 @@ visible.
 
 =head2 stop_running_process
 
-Issues a C<SIGTERM> to the active process. Returns 0 immediately if the pid
+Signals a running instance to self-terminate. Returns 0 immediately if the pid
 file does not exist or is empty. Otherwise, polls the running process until the
 OS reports that it is no longer able to receive signals (with `kill(0, $pid)`).
 
 Optional parameter C<$timeout> may be specified in fractional seconds, causing
 C<stop_running_process> to block up to (around) C<$timeout> seconds waiting for
-the signaled process to exit.
+the signaled process to exit. Optional parameter C<$sleep> specifies the
+interval between polls in fractional seconds.
 
 Returns the pid of the completed process otherwise.
 
+  $service->stop_running_process; # signal running process and return
+  $service->stop_running_process(10, 0.5); # signal, then poll every 0.5s for 10s
+
 =head2 run_lock
 
 Attempts to atomically acquire the run lock. Once held, the pid file is created
